@@ -42,6 +42,11 @@ from be_helpers.typing import List, Union
 
 class WiFiManager(object):
     """docstring for WiFiManager"""
+    ERROR = 0
+    SUCCESS = 1
+    CONNECTION_ISSUE_TIMEOUT = 1
+    CONNECTION_ISSUE_NOT_CONFIGURED = 2
+
     def __init__(self, logger=None, quiet=False, name=__name__):
         # setup and configure logger if none is provided
         if logger is None:
@@ -59,6 +64,7 @@ class WiFiManager(object):
 
         self.event_sinks = set()
 
+        self._available_urls = dict()
         self._add_app_routes()
 
         # other setup and init here
@@ -70,6 +76,8 @@ class WiFiManager(object):
 
         self._configured_networks = list()
         self._selected_network_bssid = ''
+        self._connection_timeout = 5
+        self._connection_result = self.ERROR
 
         # WiFi scan specific defines
         self._scan_lock = _thread.allocate_lock()
@@ -82,6 +90,64 @@ class WiFiManager(object):
         # start the WiFi scanning thread as soon as "start_config" is called
         self.scanning = False
 
+    @property
+    def available_urls(self) -> dict:
+        """
+        Get public available URLs.
+
+        :returns:   Dict of available URLs as keys and description as values
+        :rtype:     dict
+        """
+        return self._available_urls
+
+    @available_urls.setter
+    def available_urls(self, value: dict) -> None:
+        """
+        Set public available URLs.
+
+        This is used to render the index page content
+
+        :param      value:  New URL for index page
+        :type       value:  Dict
+        """
+        if isinstance(value, dict):
+            self._available_urls.update(value)
+
+    @property
+    def connection_timeout(self) -> int:
+        """
+        Get the WiFi connection timeout in seconds.
+
+        :returns:   Timeout if WiFi connection can not be established within
+        :rtype:     int
+        """
+        return self._connection_timeout
+
+    @connection_timeout.setter
+    def connection_timeout(self, value: int) -> None:
+        """
+        Set the WiFi connection timeout in seconds.
+
+        Values below 3 sec are set to 3 sec.
+
+        :param      value:  Timeout of WiFi connection per network in seconds
+        :type       value:  int
+        """
+        if isinstance(value, int):
+            if value < 3:
+                value = 3
+            self._connection_timeout = value
+
+    @property
+    def connection_result(self) -> int:
+        """
+        Get connection issue error code
+
+        :returns:   Connection issue error
+        :rtype:     int
+        """
+        return self._connection_result
+
     def load_and_connect(self) -> bool:
         """
         Load configured network credentials and try to connect to those
@@ -134,11 +200,15 @@ class WiFiManager(object):
             self.logger.info('Connecting to loaded network config...')
             result = WifiHelper.connect(ssid=ssids,
                                         password=passwords,
-                                        timeout=5,
+                                        timeout=self.connection_timeout,
                                         reconnect=False)
             self.logger.debug('Result of connection: {}'.format(result))
+
+            if result is False:
+                self._connection_result = self.CONNECTION_ISSUE_TIMEOUT
         else:
             self.logger.debug('WiFi config file does not (yet) exist')
+            self._connection_result = self.CONNECTION_ISSUE_NOT_CONFIGURED
 
         return result
 
@@ -190,6 +260,26 @@ class WiFiManager(object):
         self.app.add_url_rule(url=re.compile('^\/(.+\.css)$'),
                               func=self.styles)
 
+        available_urls = {
+            "/select": {
+                "title": "Select WiFi",
+                "color": "border-primary",
+                "text": "Configure WiFi networks",
+            },
+            "/configure": {
+                "title": "Manage WiFi networks",
+                "color": "border-primary",
+                "text": "Remove credentials of configured WiFi networks",
+            },
+            "/scan_result": {
+                "title": "Scan data",
+                "color": "text-white bg-info",
+                "text": "Latest WiFi scan data as JSON",
+            }
+        }
+
+        self.available_urls = available_urls
+
     def _encrypt_data(self, data: Union[str, list, dict]) -> bytes:
         """
         Encrypt data with encryption key
@@ -367,7 +457,7 @@ class WiFiManager(object):
         :param      lock:           The lock object
         :type       lock:           _thread.lock
         """
-        pixel.fading = True
+        # pixel.fading = True
 
         while lock.locked():
             try:
@@ -382,7 +472,7 @@ class WiFiManager(object):
             except KeyboardInterrupt:
                 break
 
-        pixel.fading = False
+        # pixel.fading = False
         print('Finished scanning')
 
     @property
@@ -450,14 +540,34 @@ class WiFiManager(object):
 
     @property
     def latest_scan(self) -> Union[List[dict], str]:
-        gc.collect()
-        free = gc.mem_free()
-        self.logger.debug('Free memory: {}'.format(free))
         latest_scan_result = self._scan_net_msg.value()
         self.logger.info('Requested latest scan result: {}'.
                          format(latest_scan_result))
         return latest_scan_result
 
+    def _render_index_page(self, available_pages: dict) -> str:
+        """
+        Render HTML list of available pages
+
+        :param      available_pages:    All available pages
+        :type       available_pages:    dict
+
+        :returns:   Sub content of landing page
+        :rtype:     str
+        """
+        content = ""
+
+        # sort dict by 'title' of the dict values
+        for url, info in sorted(available_pages.items(),
+                                key=lambda item: item[1]['title']):
+            content += """
+            <div class="col-sm-4 py-2"><div class="card h-100 {color}"><div class="card-body">
+                <h3 class="card-title">{title}</h3><p class="card-text">{text}</p>
+                <a href="{url}" class="stretched-link"></a></div></div></div>
+            """.format(color=info['color'], title=info['title'], text=info['text'], url=url)
+
+        return content
+
     def _render_network_inputs(self,
                                available_nets: dict,
                                selected_bssid: str = '') -> str:
@@ -610,10 +720,19 @@ class WiFiManager(object):
 
     # @app.route('/landing_page')
     def landing_page(self, req, resp) -> None:
+        """
+        Provide landing page aka index page
+
+        List of available subpages is rendered from all elements of the
+        @see available_urls property
+        """
+        available_pages = self.available_urls
+        content = self._render_index_page(available_pages)
+
         yield from picoweb.start_response(resp)
         yield from self.app.render_template(writer=resp,
                                             tmpl_name='index.tpl',
-                                            args=(req, ))
+                                            args=(req, content, ))
 
     # @app.route("/scan_result")
     def scan_result(self, req, resp) -> None:
@@ -724,7 +843,7 @@ class WiFiManager(object):
     # @app.route(re.compile('^\/(.+\.css)$'))
     def styles(self, req, resp) -> None:
         """
-        Send gzipped content if supported by client.
+        Send gzipped CSS content if supported by client.
         Shows specifying headers as a flat binary string, more efficient if
         such headers are static.
         """
@@ -746,7 +865,8 @@ class WiFiManager(object):
     def run(self,
             host: str = '0.0.0.0',
             port: int = 80,
-            debug: bool = False) -> None:
+            debug: bool = False,
+            log=None) -> None:
         """
         Run the web application
 
@@ -757,6 +877,8 @@ class WiFiManager(object):
         :param      debug:  Flag to automatically reload for code changes and
                             show debugger content
         :type       debug:  bool, optional
+        :param      log:    Logger of Picoweb
+        :type       log:    logging.Logger
         """
         self.logger.debug('Run app on {}:{} with debug: {}'.format(host,
                                                                    port,
@@ -764,7 +886,7 @@ class WiFiManager(object):
         try:
             # self.app.run()
             # self.app.run(debug=debug)
-            self.app.run(host=host, port=port, debug=debug)
+            self.app.run(host=host, port=port, debug=debug, log=log)
         except KeyboardInterrupt:
             self.logger.debug('Catched KeyboardInterrupt at run of web app')
         except Exception as e:
